"""djangocms-helper - Helpers for django CMS plugin development"""

__version__ = '0.8.1'
__author__ = 'Iacopo Spalletti <i.spalletti@nephila.it>'
__all__ = ['runner']
 

HELPER_FILE = 'cms_helper.py'
